.. Qualichat documentation master file, created by
   sphinx-quickstart on Wed May 19 16:12:49 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Qualichat!
=====================

Open-source linguistic ethnography tool for framing public opinion in mediatized groups.


Getting started
---------------

If it is your first time using this library, these resources might help.

- :doc:`intro`


Manuals
-------

These pages go into great detail about everything the API can do.

.. toctree::
   :maxdepth: 1

   api
